Usage — grobnercrystals 1.0 documentation

# Usage

## Installation

To use grobnercrystals, first install it using pip:

    $  sage --pip install grobnercrystals

Alternatively, grobnercrystals may be installed by running:

    $ sage --pip install git+https://github.com/LiberMagnum/grobnercrystals.git#egg=grobnercrystals

The package can then be imported at the beginning of any SageMath script:

    import grobnercrystals

## Dependencies

Details on installing SageMath may be found here.

Grobnercrystals requires a Macaulay2 installation; details on how to install Macaulay2 may be found here. Grobnercrystals also requires the Macaulay2 package “gfanInterface”.

Grobnercrystals relies on numpy for many of its functions. Numpy may be installed by running:

    $ pip install numpy